import 'package:yoshi_papas_app/views/categoria_producto/categoria_producto_form.dart';
import 'package:flutter/material.dart';
import '../../themes/themes.dart';
import '../../viewmodels/viewmodels.dart';
import 'package:provider/provider.dart';

class CategoriaProductoScreen extends StatefulWidget {
  const CategoriaProductoScreen({Key? key}) : super(key: key);

  @override
  State<CategoriaProductoScreen> createState() => _CategoriaProductoState();
}

class _CategoriaProductoState extends State<CategoriaProductoScreen> {
  @override
  void initState() {
    super.initState();
    final viewModel =
        Provider.of<CategoriaProductoViewModel>(context, listen: false);
    Future(() async {
      viewModel.setLoading(true);
      await viewModel.fetchCategoriaProductos();
      viewModel.setLoading(false);
    });
  }

  @override
  Widget build(BuildContext context) {
    final viewModel = Provider.of<CategoriaProductoViewModel>(context);
    final categoriaProductos = viewModel.categoriaProductos;
    final isLoading = viewModel.isLoading;

    return Scaffold(
      floatingActionButton: Padding(
        padding: const EdgeInsets.only(right: 50.0),
        child: FloatingActionButton(
            onPressed: () async {
              Navigator.push(
                context,
                MaterialPageRoute(
                  builder: (context) => const CategoriaProductoForm(),
                ),
              ).then((result) async {
                if (result != null) {
                  viewModel.setLoading(true);
                  await viewModel.addCategoriaProducto(
                    nombre: result.nombre,
                  );
                  viewModel.setLoading(false);
                }
              });
            },
            child: const Icon(
              Icons.add,
              size: 30,
            )),
      ),
      appBar: AppBar(
        title: const Text('Categoria Producto'),
      ),
      body: Center(
        child: isLoading
            ? const Center(
                child: CircularProgressIndicator(),
              )
            : ListView.separated(
                itemCount: categoriaProductos.length,
                itemBuilder: (context, index) {
                  var categoriaProducto = categoriaProductos[index];
                  return ListTile(
                    onTap: () {
                      viewModel.selectCategoriaProducto(categoriaProducto);
                    },
                    title: Text(categoriaProducto.nombre!),
                    trailing: PopupMenuButton(
                      surfaceTintColor: AppTheme.quaternary,
                      itemBuilder: (context) => [
                        PopupMenuItem(
                          child: const Text('Editar'),
                          onTap: () {
                            Navigator.push(
                              context,
                              MaterialPageRoute(
                                builder: (context) =>
                                    const CategoriaProductoForm(),
                              ),
                            ).then((result) async {
                              if (result != null) {
                                viewModel.setLoading(true);
                                await viewModel.editCategoriaProducto(
                                  id: categoriaProducto.id,
                                  nombre: result.nombre,
                                );
                                viewModel.setLoading(false);
                              }
                            });
                          },
                        ),
                        PopupMenuItem(
                          child: const Text(
                            'Eliminar',
                            style: TextStyle(color: Colors.red),
                          ),
                          onTap: () {
                            showDialog(
                              context: context,
                              builder: (context) {
                                return AlertDialog(
                                  title:
                                      const Text('Eliminar CategoriaProducto'),
                                  content: const Text(
                                      '¿Estás seguro de que quieres eliminar esta categoriaProducto?'),
                                  actions: [
                                    TextButton(
                                      onPressed: () {
                                        Navigator.pop(context);
                                      },
                                      child: const Text('Cancelar'),
                                    ),
                                    TextButton(
                                      onPressed: () async {
                                        Navigator.pop(context);
                                        viewModel.setLoading(true);
                                        await viewModel.deleteCategoriaProducto(
                                            categoriaProducto.id);
                                        viewModel.setLoading(false);
                                      },
                                      child: const Text('Eliminar'),
                                    ),
                                  ],
                                );
                              },
                            );
                          },
                        )
                      ],
                      icon: const Icon(Icons.more_vert),
                      shape: RoundedRectangleBorder(
                          borderRadius: BorderRadius.circular(15)),
                    ),
                  );
                },
                separatorBuilder: (context, index) => const Divider(
                  height: 0,
                  thickness: 0,
                  color: Colors.grey,
                ),
              ),
      ),
    );
  }
}
